# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/routing/v1/peer.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/routing/v1/peer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n agntcy/dir/routing/v1/peer.proto\x12\x15\x61gntcy.dir.routing.v1\"\x87\x02\n\x04Peer\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x61\x64\x64rs\x18\x02 \x03(\tR\x05\x61\x64\x64rs\x12N\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32,.agntcy.dir.routing.v1.Peer.AnnotationsEntryR\x0b\x61nnotations\x12I\n\nconnection\x18\x04 \x01(\x0e\x32).agntcy.dir.routing.v1.PeerConnectionTypeR\nconnection\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xaf\x01\n\x12PeerConnectionType\x12&\n\"PEER_CONNECTION_TYPE_NOT_CONNECTED\x10\x00\x12\"\n\x1ePEER_CONNECTION_TYPE_CONNECTED\x10\x01\x12$\n PEER_CONNECTION_TYPE_CAN_CONNECT\x10\x02\x12\'\n#PEER_CONNECTION_TYPE_CANNOT_CONNECT\x10\x03\x42\xc3\x01\n\x19\x63om.agntcy.dir.routing.v1B\tPeerProtoP\x01Z$github.com/agntcy/dir/api/routing/v1\xa2\x02\x03\x41\x44R\xaa\x02\x15\x41gntcy.Dir.Routing.V1\xca\x02\x15\x41gntcy\\Dir\\Routing\\V1\xe2\x02!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\xea\x02\x18\x41gntcy::Dir::Routing::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.routing.v1.peer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.agntcy.dir.routing.v1B\tPeerProtoP\001Z$github.com/agntcy/dir/api/routing/v1\242\002\003ADR\252\002\025Agntcy.Dir.Routing.V1\312\002\025Agntcy\\Dir\\Routing\\V1\342\002!Agntcy\\Dir\\Routing\\V1\\GPBMetadata\352\002\030Agntcy::Dir::Routing::V1'
  _globals['_PEER_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_PEER_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_PEERCONNECTIONTYPE']._serialized_start=326
  _globals['_PEERCONNECTIONTYPE']._serialized_end=501
  _globals['_PEER']._serialized_start=60
  _globals['_PEER']._serialized_end=323
  _globals['_PEER_ANNOTATIONSENTRY']._serialized_start=261
  _globals['_PEER_ANNOTATIONSENTRY']._serialized_end=323
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TYPE_UNSPECIFIED: _ClassVar[EventType]
    EVENT_TYPE_RECORD_PUSHED: _ClassVar[EventType]
    EVENT_TYPE_RECORD_PULLED: _ClassVar[EventType]
    EVENT_TYPE_RECORD_DELETED: _ClassVar[EventType]
    EVENT_TYPE_RECORD_PUBLISHED: _ClassVar[EventType]
    EVENT_TYPE_RECORD_UNPUBLISHED: _ClassVar[EventType]
    EVENT_TYPE_SYNC_CREATED: _ClassVar[EventType]
    EVENT_TYPE_SYNC_COMPLETED: _ClassVar[EventType]
    EVENT_TYPE_SYNC_FAILED: _ClassVar[EventType]
    EVENT_TYPE_RECORD_SIGNED: _ClassVar[EventType]
    EVENT_TYPE_PUBLIC_KEY_UPLOADED: _ClassVar[EventType]
EVENT_TYPE_UNSPECIFIED: EventType
EVENT_TYPE_RECORD_PUSHED: EventType
EVENT_TYPE_RECORD_PULLED: EventType
EVENT_TYPE_RECORD_DELETED: EventType
EVENT_TYPE_RECORD_PUBLISHED: EventType
EVENT_TYPE_RECORD_UNPUBLISHED: EventType
EVENT_TYPE_SYNC_CREATED: EventType
EVENT_TYPE_SYNC_COMPLETED: EventType
EVENT_TYPE_SYNC_FAILED: EventType
EVENT_TYPE_RECORD_SIGNED: EventType
EVENT_TYPE_PUBLIC_KEY_UPLOADED: EventType

class ListenRequest(_message.Message):
    __slots__ = ("event_types", "label_filters", "cid_filters")
    EVENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    LABEL_FILTERS_FIELD_NUMBER: _ClassVar[int]
    CID_FILTERS_FIELD_NUMBER: _ClassVar[int]
    event_types: _containers.RepeatedScalarFieldContainer[EventType]
    label_filters: _containers.RepeatedScalarFieldContainer[str]
    cid_filters: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, event_types: _Optional[_Iterable[_Union[EventType, str]]] = ..., label_filters: _Optional[_Iterable[str]] = ..., cid_filters: _Optional[_Iterable[str]] = ...) -> None: ...

class ListenResponse(_message.Message):
    __slots__ = ("event",)
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event: Event
    def __init__(self, event: _Optional[_Union[Event, _Mapping]] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("id", "type", "timestamp", "resource_id", "labels", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: EventType
    timestamp: _timestamp_pb2.Timestamp
    resource_id: str
    labels: _containers.RepeatedScalarFieldContainer[str]
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[EventType, str]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., resource_id: _Optional[str] = ..., labels: _Optional[_Iterable[str]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/search/v1/search_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/search/v1/search_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agntcy.dir.core.v1 import record_pb2 as agntcy_dot_dir_dot_core_dot_v1_dot_record__pb2
from agntcy.dir.search.v1 import record_query_pb2 as agntcy_dot_dir_dot_search_dot_v1_dot_record__query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)agntcy/dir/search/v1/search_service.proto\x12\x14\x61gntcy.dir.search.v1\x1a\x1f\x61gntcy/dir/core/v1/record.proto\x1a\'agntcy/dir/search/v1/record_query.proto\"\x9d\x01\n\x11SearchCIDsRequest\x12;\n\x07queries\x18\x01 \x03(\x0b\x32!.agntcy.dir.search.v1.RecordQueryR\x07queries\x12\x19\n\x05limit\x18\x02 \x01(\rH\x00R\x05limit\x88\x01\x01\x12\x1b\n\x06offset\x18\x03 \x01(\rH\x01R\x06offset\x88\x01\x01\x42\x08\n\x06_limitB\t\n\x07_offset\"\xa0\x01\n\x14SearchRecordsRequest\x12;\n\x07queries\x18\x01 \x03(\x0b\x32!.agntcy.dir.search.v1.RecordQueryR\x07queries\x12\x19\n\x05limit\x18\x02 \x01(\rH\x00R\x05limit\x88\x01\x01\x12\x1b\n\x06offset\x18\x03 \x01(\rH\x01R\x06offset\x88\x01\x01\x42\x08\n\x06_limitB\t\n\x07_offset\"3\n\x12SearchCIDsResponse\x12\x1d\n\nrecord_cid\x18\x01 \x01(\tR\trecordCid\"K\n\x15SearchRecordsResponse\x12\x32\n\x06record\x18\x01 \x01(\x0b\x32\x1a.agntcy.dir.core.v1.RecordR\x06record2\xde\x01\n\rSearchService\x12\x61\n\nSearchCIDs\x12\'.agntcy.dir.search.v1.SearchCIDsRequest\x1a(.agntcy.dir.search.v1.SearchCIDsResponse0\x01\x12j\n\rSearchRecords\x12*.agntcy.dir.search.v1.SearchRecordsRequest\x1a+.agntcy.dir.search.v1.SearchRecordsResponse0\x01\x42\xc6\x01\n\x18\x63om.agntcy.dir.search.v1B\x12SearchServiceProtoP\x01Z#github.com/agntcy/dir/api/search/v1\xa2\x02\x03\x41\x44S\xaa\x02\x14\x41gntcy.Dir.Search.V1\xca\x02\x14\x41gntcy\\Dir\\Search\\V1\xe2\x02 Agntcy\\Dir\\Search\\V1\\GPBMetadata\xea\x02\x17\x41gntcy::Dir::Search::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.search.v1.search_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.agntcy.dir.search.v1B\022SearchServiceProtoP\001Z#github.com/agntcy/dir/api/search/v1\242\002\003ADS\252\002\024Agntcy.Dir.Search.V1\312\002\024Agntcy\\Dir\\Search\\V1\342\002 Agntcy\\Dir\\Search\\V1\\GPBMetadata\352\002\027Agntcy::Dir::Search::V1'
  _globals['_SEARCHCIDSREQUEST']._serialized_start=142
  _globals['_SEARCHCIDSREQUEST']._serialized_end=299
  _globals['_SEARCHRECORDSREQUEST']._serialized_start=302
  _globals['_SEARCHRECORDSREQUEST']._serialized_end=462
  _globals['_SEARCHCIDSRESPONSE']._serialized_start=464
  _globals['_SEARCHCIDSRESPONSE']._serialized_end=515
  _globals['_SEARCHRECORDSRESPONSE']._serialized_start=517
  _globals['_SEARCHRECORDSRESPONSE']._serialized_end=592
  _globals['_SEARCHSERVICE']._serialized_start=595
  _globals['_SEARCHSERVICE']._serialized_end=817
# @@protoc_insertion_point(module_scope)



# Copyright AGNTCY Contributors (https://github.com/agntcy)
# SPDX-License-Identifier: Apache-2.0

# Export all protobuf packages for easier module imports.
# The actual subpackages in agntcy_dir.models expose gRPC stubs.

import agntcy.dir_sdk.models.core_v1 as core_v1
import agntcy.dir_sdk.models.naming_v1 as naming_v1
import agntcy.dir_sdk.models.routing_v1 as routing_v1
import agntcy.dir_sdk.models.search_v1 as search_v1
import agntcy.dir_sdk.models.sign_v1 as sign_v1
import agntcy.dir_sdk.models.store_v1 as store_v1
import agntcy.dir_sdk.models.events_v1 as events_v1



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RecordQueryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RECORD_QUERY_TYPE_UNSPECIFIED: _ClassVar[RecordQueryType]
    RECORD_QUERY_TYPE_SKILL: _ClassVar[RecordQueryType]
    RECORD_QUERY_TYPE_LOCATOR: _ClassVar[RecordQueryType]
    RECORD_QUERY_TYPE_DOMAIN: _ClassVar[RecordQueryType]
    RECORD_QUERY_TYPE_MODULE: _ClassVar[RecordQueryType]
RECORD_QUERY_TYPE_UNSPECIFIED: RecordQueryType
RECORD_QUERY_TYPE_SKILL: RecordQueryType
RECORD_QUERY_TYPE_LOCATOR: RecordQueryType
RECORD_QUERY_TYPE_DOMAIN: RecordQueryType
RECORD_QUERY_TYPE_MODULE: RecordQueryType

class RecordQuery(_message.Message):
    __slots__ = ("type", "value")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type: RecordQueryType
    value: str
    def __init__(self, type: _Optional[_Union[RecordQueryType, str]] = ..., value: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from agntcy.dir.events.v1 import event_service_pb2 as agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2


class EventServiceStub(object):
    """EventService provides real-time event streaming for all system operations.
    Events are delivered from subscription time forward with no history or replay.
    This service enables external applications to react to system changes in real-time.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Listen = channel.unary_stream(
                '/agntcy.dir.events.v1.EventService/Listen',
                request_serializer=agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2.ListenRequest.SerializeToString,
                response_deserializer=agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2.ListenResponse.FromString,
                _registered_method=True)


class EventServiceServicer(object):
    """EventService provides real-time event streaming for all system operations.
    Events are delivered from subscription time forward with no history or replay.
    This service enables external applications to react to system changes in real-time.
    """

    def Listen(self, request, context):
        """Listen establishes a streaming connection to receive events.
        Events are only delivered while the stream is active.
        On disconnect, missed events are not recoverable.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Listen': grpc.unary_stream_rpc_method_handler(
                    servicer.Listen,
                    request_deserializer=agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2.ListenRequest.FromString,
                    response_serializer=agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2.ListenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'agntcy.dir.events.v1.EventService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('agntcy.dir.events.v1.EventService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class EventService(object):
    """EventService provides real-time event streaming for all system operations.
    Events are delivered from subscription time forward with no history or replay.
    This service enables external applications to react to system changes in real-time.
    """

    @staticmethod
    def Listen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/agntcy.dir.events.v1.EventService/Listen',
            agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2.ListenRequest.SerializeToString,
            agntcy_dot_dir_dot_events_dot_v1_dot_event__service__pb2.ListenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from agntcy.dir.search.v1 import search_service_pb2 as agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2


class SearchServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SearchCIDs = channel.unary_stream(
                '/agntcy.dir.search.v1.SearchService/SearchCIDs',
                request_serializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchCIDsRequest.SerializeToString,
                response_deserializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchCIDsResponse.FromString,
                _registered_method=True)
        self.SearchRecords = channel.unary_stream(
                '/agntcy.dir.search.v1.SearchService/SearchRecords',
                request_serializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchRecordsRequest.SerializeToString,
                response_deserializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchRecordsResponse.FromString,
                _registered_method=True)


class SearchServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SearchCIDs(self, request, context):
        """Search for record CIDs that match the given parameters.
        Returns only CIDs for efficient lookups and piping to other commands.
        This operation does not interact with the network.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchRecords(self, request, context):
        """Search for full records that match the given parameters.
        Returns complete record data including all metadata, skills, domains, etc.
        This operation does not interact with the network.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SearchCIDs': grpc.unary_stream_rpc_method_handler(
                    servicer.SearchCIDs,
                    request_deserializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchCIDsRequest.FromString,
                    response_serializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchCIDsResponse.SerializeToString,
            ),
            'SearchRecords': grpc.unary_stream_rpc_method_handler(
                    servicer.SearchRecords,
                    request_deserializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchRecordsRequest.FromString,
                    response_serializer=agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchRecordsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'agntcy.dir.search.v1.SearchService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('agntcy.dir.search.v1.SearchService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SearchService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SearchCIDs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/agntcy.dir.search.v1.SearchService/SearchCIDs',
            agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchCIDsRequest.SerializeToString,
            agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchCIDsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/agntcy.dir.search.v1.SearchService/SearchRecords',
            agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchRecordsRequest.SerializeToString,
            agntcy_dot_dir_dot_search_dot_v1_dot_search__service__pb2.SearchRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from agntcy.dir.core.v1 import record_pb2 as _record_pb2
from agntcy.dir.naming.v1 import name_verification_pb2 as _name_verification_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetVerificationInfoRequest(_message.Message):
    __slots__ = ("cid", "name", "version")
    CID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    cid: str
    name: str
    version: str
    def __init__(self, cid: _Optional[str] = ..., name: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class GetVerificationInfoResponse(_message.Message):
    __slots__ = ("verified", "verification", "error_message")
    VERIFIED_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    verified: bool
    verification: _name_verification_pb2.Verification
    error_message: str
    def __init__(self, verified: bool = ..., verification: _Optional[_Union[_name_verification_pb2.Verification, _Mapping]] = ..., error_message: _Optional[str] = ...) -> None: ...

class ResolveRequest(_message.Message):
    __slots__ = ("name", "version")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class ResolveResponse(_message.Message):
    __slots__ = ("records",)
    RECORDS_FIELD_NUMBER: _ClassVar[int]
    records: _containers.RepeatedCompositeFieldContainer[_record_pb2.NamedRecordRef]
    def __init__(self, records: _Optional[_Iterable[_Union[_record_pb2.NamedRecordRef, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from agntcy.dir.routing.v1 import publication_service_pb2 as agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2
from agntcy.dir.routing.v1 import routing_service_pb2 as agntcy_dot_dir_dot_routing_dot_v1_dot_routing__service__pb2


class PublicationServiceStub(object):
    """PublicationService manages publication requests for announcing records to the DHT.

    Publications are stored in the database and processed by a worker that runs every hour.
    The publication workflow:
    1. Publications are created via routing's Publish RPC by specifying either a query, a list of CIDs, or all records
    2. Publication requests are added to the database
    3. PublicationWorker queries the data using the publication request from the database to get the list of CIDs to be published
    4. PublicationWorker announces the records with these CIDs to the DHT
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreatePublication = channel.unary_unary(
                '/agntcy.dir.routing.v1.PublicationService/CreatePublication',
                request_serializer=agntcy_dot_dir_dot_routing_dot_v1_dot_routing__service__pb2.PublishRequest.SerializeToString,
                response_deserializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.CreatePublicationResponse.FromString,
                _registered_method=True)
        self.ListPublications = channel.unary_stream(
                '/agntcy.dir.routing.v1.PublicationService/ListPublications',
                request_serializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.ListPublicationsRequest.SerializeToString,
                response_deserializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.ListPublicationsItem.FromString,
                _registered_method=True)
        self.GetPublication = channel.unary_unary(
                '/agntcy.dir.routing.v1.PublicationService/GetPublication',
                request_serializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.GetPublicationRequest.SerializeToString,
                response_deserializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.GetPublicationResponse.FromString,
                _registered_method=True)


class PublicationServiceServicer(object):
    """PublicationService manages publication requests for announcing records to the DHT.

    Publications are stored in the database and processed by a worker that runs every hour.
    The publication workflow:
    1. Publications are created via routing's Publish RPC by specifying either a query, a list of CIDs, or all records
    2. Publication requests are added to the database
    3. PublicationWorker queries the data using the publication request from the database to get the list of CIDs to be published
    4. PublicationWorker announces the records with these CIDs to the DHT
    """

    def CreatePublication(self, request, context):
        """CreatePublication creates a new publication request that will be processed by the PublicationWorker.
        The publication request can specify either a query, a list of specific CIDs, or all records to be announced to the DHT.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPublications(self, request, context):
        """ListPublications returns a stream of all publication requests in the system.
        This allows monitoring of pending, processing, and completed publication requests.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPublication(self, request, context):
        """GetPublication retrieves details of a specific publication request by its identifier.
        This includes the current status and any associated metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PublicationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreatePublication': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePublication,
                    request_deserializer=agntcy_dot_dir_dot_routing_dot_v1_dot_routing__service__pb2.PublishRequest.FromString,
                    response_serializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.CreatePublicationResponse.SerializeToString,
            ),
            'ListPublications': grpc.unary_stream_rpc_method_handler(
                    servicer.ListPublications,
                    request_deserializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.ListPublicationsRequest.FromString,
                    response_serializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.ListPublicationsItem.SerializeToString,
            ),
            'GetPublication': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPublication,
                    request_deserializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.GetPublicationRequest.FromString,
                    response_serializer=agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.GetPublicationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'agntcy.dir.routing.v1.PublicationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('agntcy.dir.routing.v1.PublicationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PublicationService(object):
    """PublicationService manages publication requests for announcing records to the DHT.

    Publications are stored in the database and processed by a worker that runs every hour.
    The publication workflow:
    1. Publications are created via routing's Publish RPC by specifying either a query, a list of CIDs, or all records
    2. Publication requests are added to the database
    3. PublicationWorker queries the data using the publication request from the database to get the list of CIDs to be published
    4. PublicationWorker announces the records with these CIDs to the DHT
    """

    @staticmethod
    def CreatePublication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/agntcy.dir.routing.v1.PublicationService/CreatePublication',
            agntcy_dot_dir_dot_routing_dot_v1_dot_routing__service__pb2.PublishRequest.SerializeToString,
            agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.CreatePublicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPublications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/agntcy.dir.routing.v1.PublicationService/ListPublications',
            agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.ListPublicationsRequest.SerializeToString,
            agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.ListPublicationsItem.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPublication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/agntcy.dir.routing.v1.PublicationService/GetPublication',
            agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.GetPublicationRequest.SerializeToString,
            agntcy_dot_dir_dot_routing_dot_v1_dot_publication__service__pb2.GetPublicationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/events/v1/event_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/events/v1/event_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(agntcy/dir/events/v1/event_service.proto\x12\x14\x61gntcy.dir.events.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x97\x01\n\rListenRequest\x12@\n\x0b\x65vent_types\x18\x01 \x03(\x0e\x32\x1f.agntcy.dir.events.v1.EventTypeR\neventTypes\x12#\n\rlabel_filters\x18\x02 \x03(\tR\x0clabelFilters\x12\x1f\n\x0b\x63id_filters\x18\x03 \x03(\tR\ncidFilters\"C\n\x0eListenResponse\x12\x31\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1b.agntcy.dir.events.v1.EventR\x05\x65vent\"\xc3\x02\n\x05\x45vent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32\x1f.agntcy.dir.events.v1.EventTypeR\x04type\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x1f\n\x0bresource_id\x18\x04 \x01(\tR\nresourceId\x12\x16\n\x06labels\x18\x05 \x03(\tR\x06labels\x12\x45\n\x08metadata\x18\x07 \x03(\x0b\x32).agntcy.dir.events.v1.Event.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xe0\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45VENT_TYPE_RECORD_PUSHED\x10\x01\x12\x1c\n\x18\x45VENT_TYPE_RECORD_PULLED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_RECORD_DELETED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_RECORD_PUBLISHED\x10\x04\x12!\n\x1d\x45VENT_TYPE_RECORD_UNPUBLISHED\x10\x05\x12\x1b\n\x17\x45VENT_TYPE_SYNC_CREATED\x10\x06\x12\x1d\n\x19\x45VENT_TYPE_SYNC_COMPLETED\x10\x07\x12\x1a\n\x16\x45VENT_TYPE_SYNC_FAILED\x10\x08\x12\x1c\n\x18\x45VENT_TYPE_RECORD_SIGNED\x10\t\x12\"\n\x1e\x45VENT_TYPE_PUBLIC_KEY_UPLOADED\x10\n2e\n\x0c\x45ventService\x12U\n\x06Listen\x12#.agntcy.dir.events.v1.ListenRequest\x1a$.agntcy.dir.events.v1.ListenResponse0\x01\x42\xc5\x01\n\x18\x63om.agntcy.dir.events.v1B\x11\x45ventServiceProtoP\x01Z#github.com/agntcy/dir/api/events/v1\xa2\x02\x03\x41\x44\x45\xaa\x02\x14\x41gntcy.Dir.Events.V1\xca\x02\x14\x41gntcy\\Dir\\Events\\V1\xe2\x02 Agntcy\\Dir\\Events\\V1\\GPBMetadata\xea\x02\x17\x41gntcy::Dir::Events::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.events.v1.event_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.agntcy.dir.events.v1B\021EventServiceProtoP\001Z#github.com/agntcy/dir/api/events/v1\242\002\003ADE\252\002\024Agntcy.Dir.Events.V1\312\002\024Agntcy\\Dir\\Events\\V1\342\002 Agntcy\\Dir\\Events\\V1\\GPBMetadata\352\002\027Agntcy::Dir::Events::V1'
  _globals['_EVENT_METADATAENTRY']._loaded_options = None
  _globals['_EVENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTTYPE']._serialized_start=649
  _globals['_EVENTTYPE']._serialized_end=1001
  _globals['_LISTENREQUEST']._serialized_start=100
  _globals['_LISTENREQUEST']._serialized_end=251
  _globals['_LISTENRESPONSE']._serialized_start=253
  _globals['_LISTENRESPONSE']._serialized_end=320
  _globals['_EVENT']._serialized_start=323
  _globals['_EVENT']._serialized_end=646
  _globals['_EVENT_METADATAENTRY']._serialized_start=587
  _globals['_EVENT_METADATAENTRY']._serialized_end=646
  _globals['_EVENTSERVICE']._serialized_start=1003
  _globals['_EVENTSERVICE']._serialized_end=1104
# @@protoc_insertion_point(module_scope)



# Copyright AGNTCY Contributors (https://github.com/agntcy)
# SPDX-License-Identifier: Apache-2.0

import os


class Config:
    DEFAULT_SERVER_ADDRESS = "127.0.0.1:8888"
    DEFAULT_DIRCTL_PATH = "dirctl"
    DEFAULT_SPIFFE_SOCKET_PATH = ""
    DEFAULT_AUTH_MODE = ""
    DEFAULT_JWT_AUDIENCE = ""
    DEFAULT_TLS_CA_FILE = ""
    DEFAULT_TLS_CERT_FILE = ""
    DEFAULT_TLS_KEY_FILE = ""

    def __init__(
        self,
        server_address: str = DEFAULT_SERVER_ADDRESS,
        dirctl_path: str = DEFAULT_DIRCTL_PATH,
        spiffe_socket_path: str = DEFAULT_SPIFFE_SOCKET_PATH,
        auth_mode: str = DEFAULT_AUTH_MODE,
        jwt_audience: str = DEFAULT_JWT_AUDIENCE,
        tls_ca_file: str = DEFAULT_TLS_CA_FILE,
        tls_cert_file: str = DEFAULT_TLS_CERT_FILE,
        tls_key_file: str = DEFAULT_TLS_KEY_FILE,
    ) -> None:
        self.server_address = server_address
        self.dirctl_path = dirctl_path
        self.spiffe_socket_path = spiffe_socket_path
        self.auth_mode = auth_mode  # '' for insecure, 'x509', 'jwt' or 'tls'
        self.jwt_audience = jwt_audience
        self.tls_ca_file = tls_ca_file
        self.tls_cert_file = tls_cert_file
        self.tls_key_file = tls_key_file

    @staticmethod
    def load_from_env(env_prefix: str = "DIRECTORY_CLIENT_") -> "Config":
        """Load configuration from environment variables."""
        # Get dirctl path from environment variable without prefix
        dirctl_path = os.environ.get(
            "DIRCTL_PATH",
            Config.DEFAULT_DIRCTL_PATH,
        )

        # Use prefixed environment variables for other settings
        server_address = os.environ.get(
            f"{env_prefix}SERVER_ADDRESS",
            Config.DEFAULT_SERVER_ADDRESS,
        )
        spiffe_socket_path = os.environ.get(
            f"{env_prefix}SPIFFE_SOCKET_PATH",
            Config.DEFAULT_SPIFFE_SOCKET_PATH,
        )
        auth_mode = os.environ.get(
            f"{env_prefix}AUTH_MODE",
            Config.DEFAULT_AUTH_MODE,
        )
        jwt_audience = os.environ.get(
            f"{env_prefix}JWT_AUDIENCE",
            Config.DEFAULT_JWT_AUDIENCE,
        )
        tls_ca_file = os.environ.get(
            f"{env_prefix}TLS_CA_FILE",
            Config.DEFAULT_TLS_CA_FILE,
        )
        tls_cert_file = os.environ.get(
            f"{env_prefix}TLS_CERT_FILE",
            Config.DEFAULT_TLS_CERT_FILE,
        )
        tls_key_file = os.environ.get(
            f"{env_prefix}TLS_KEY_FILE",
            Config.DEFAULT_TLS_KEY_FILE,
        )

        return Config(
            server_address=server_address,
            dirctl_path=dirctl_path,
            spiffe_socket_path=spiffe_socket_path,
            auth_mode=auth_mode,
            jwt_audience=jwt_audience,
            tls_ca_file=tls_ca_file,
            tls_cert_file=tls_cert_file,
            tls_key_file=tls_key_file,
        )



# Copyright AGNTCY Contributors (https://github.com/agntcy)
# SPDX-License-Identifier: Apache-2.0

from agntcy.dir.events.v1.event_service_pb2 import *
from agntcy.dir.events.v1.event_service_pb2_grpc import *



from agntcy.dir.core.v1 import record_pb2 as _record_pb2
from agntcy.dir.search.v1 import record_query_pb2 as _record_query_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SearchCIDsRequest(_message.Message):
    __slots__ = ("queries", "limit", "offset")
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    queries: _containers.RepeatedCompositeFieldContainer[_record_query_pb2.RecordQuery]
    limit: int
    offset: int
    def __init__(self, queries: _Optional[_Iterable[_Union[_record_query_pb2.RecordQuery, _Mapping]]] = ..., limit: _Optional[int] = ..., offset: _Optional[int] = ...) -> None: ...

class SearchRecordsRequest(_message.Message):
    __slots__ = ("queries", "limit", "offset")
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    queries: _containers.RepeatedCompositeFieldContainer[_record_query_pb2.RecordQuery]
    limit: int
    offset: int
    def __init__(self, queries: _Optional[_Iterable[_Union[_record_query_pb2.RecordQuery, _Mapping]]] = ..., limit: _Optional[int] = ..., offset: _Optional[int] = ...) -> None: ...

class SearchCIDsResponse(_message.Message):
    __slots__ = ("record_cid",)
    RECORD_CID_FIELD_NUMBER: _ClassVar[int]
    record_cid: str
    def __init__(self, record_cid: _Optional[str] = ...) -> None: ...

class SearchRecordsResponse(_message.Message):
    __slots__ = ("record",)
    RECORD_FIELD_NUMBER: _ClassVar[int]
    record: _record_pb2.Record
    def __init__(self, record: _Optional[_Union[_record_pb2.Record, _Mapping]] = ...) -> None: ...



# Copyright AGNTCY Contributors (https://github.com/agntcy)
# SPDX-License-Identifier: Apache-2.0

from agntcy.dir.routing.v1.peer_pb2 import *
from agntcy.dir.routing.v1.peer_pb2_grpc import *
from agntcy.dir.routing.v1.publication_service_pb2 import *
from agntcy.dir.routing.v1.publication_service_pb2_grpc import *
from agntcy.dir.routing.v1.record_query_pb2 import *
from agntcy.dir.routing.v1.record_query_pb2_grpc import *
from agntcy.dir.routing.v1.routing_service_pb2 import *
from agntcy.dir.routing.v1.routing_service_pb2_grpc import *



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SyncStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SYNC_STATUS_UNSPECIFIED: _ClassVar[SyncStatus]
    SYNC_STATUS_PENDING: _ClassVar[SyncStatus]
    SYNC_STATUS_IN_PROGRESS: _ClassVar[SyncStatus]
    SYNC_STATUS_FAILED: _ClassVar[SyncStatus]
    SYNC_STATUS_DELETE_PENDING: _ClassVar[SyncStatus]
    SYNC_STATUS_DELETED: _ClassVar[SyncStatus]
    SYNC_STATUS_COMPLETED: _ClassVar[SyncStatus]
SYNC_STATUS_UNSPECIFIED: SyncStatus
SYNC_STATUS_PENDING: SyncStatus
SYNC_STATUS_IN_PROGRESS: SyncStatus
SYNC_STATUS_FAILED: SyncStatus
SYNC_STATUS_DELETE_PENDING: SyncStatus
SYNC_STATUS_DELETED: SyncStatus
SYNC_STATUS_COMPLETED: SyncStatus

class CreateSyncRequest(_message.Message):
    __slots__ = ("remote_directory_url", "cids")
    REMOTE_DIRECTORY_URL_FIELD_NUMBER: _ClassVar[int]
    CIDS_FIELD_NUMBER: _ClassVar[int]
    remote_directory_url: str
    cids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, remote_directory_url: _Optional[str] = ..., cids: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateSyncResponse(_message.Message):
    __slots__ = ("sync_id",)
    SYNC_ID_FIELD_NUMBER: _ClassVar[int]
    sync_id: str
    def __init__(self, sync_id: _Optional[str] = ...) -> None: ...

class ListSyncsRequest(_message.Message):
    __slots__ = ("limit", "offset")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    limit: int
    offset: int
    def __init__(self, limit: _Optional[int] = ..., offset: _Optional[int] = ...) -> None: ...

class ListSyncsItem(_message.Message):
    __slots__ = ("sync_id", "status", "remote_directory_url")
    SYNC_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    REMOTE_DIRECTORY_URL_FIELD_NUMBER: _ClassVar[int]
    sync_id: str
    status: SyncStatus
    remote_directory_url: str
    def __init__(self, sync_id: _Optional[str] = ..., status: _Optional[_Union[SyncStatus, str]] = ..., remote_directory_url: _Optional[str] = ...) -> None: ...

class GetSyncRequest(_message.Message):
    __slots__ = ("sync_id",)
    SYNC_ID_FIELD_NUMBER: _ClassVar[int]
    sync_id: str
    def __init__(self, sync_id: _Optional[str] = ...) -> None: ...

class GetSyncResponse(_message.Message):
    __slots__ = ("sync_id", "status", "remote_directory_url", "created_time", "last_update_time")
    SYNC_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    REMOTE_DIRECTORY_URL_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    sync_id: str
    status: SyncStatus
    remote_directory_url: str
    created_time: str
    last_update_time: str
    def __init__(self, sync_id: _Optional[str] = ..., status: _Optional[_Union[SyncStatus, str]] = ..., remote_directory_url: _Optional[str] = ..., created_time: _Optional[str] = ..., last_update_time: _Optional[str] = ...) -> None: ...

class DeleteSyncRequest(_message.Message):
    __slots__ = ("sync_id",)
    SYNC_ID_FIELD_NUMBER: _ClassVar[int]
    sync_id: str
    def __init__(self, sync_id: _Optional[str] = ...) -> None: ...

class DeleteSyncResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestRegistryCredentialsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestRegistryCredentialsResponse(_message.Message):
    __slots__ = ("success", "error_message", "registry_address", "repository_name", "basic_auth", "insecure")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REGISTRY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    REPOSITORY_NAME_FIELD_NUMBER: _ClassVar[int]
    BASIC_AUTH_FIELD_NUMBER: _ClassVar[int]
    INSECURE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    registry_address: str
    repository_name: str
    basic_auth: BasicAuthCredentials
    insecure: bool
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ..., registry_address: _Optional[str] = ..., repository_name: _Optional[str] = ..., basic_auth: _Optional[_Union[BasicAuthCredentials, _Mapping]] = ..., insecure: bool = ...) -> None: ...

class BasicAuthCredentials(_message.Message):
    __slots__ = ("username", "password")
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    username: str
    password: str
    def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/search/v1/record_query.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/search/v1/record_query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'agntcy/dir/search/v1/record_query.proto\x12\x14\x61gntcy.dir.search.v1\"^\n\x0bRecordQuery\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32%.agntcy.dir.search.v1.RecordQueryTypeR\x04type\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value*\xfd\x03\n\x0fRecordQueryType\x12!\n\x1dRECORD_QUERY_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16RECORD_QUERY_TYPE_NAME\x10\x01\x12\x1d\n\x19RECORD_QUERY_TYPE_VERSION\x10\x02\x12\x1e\n\x1aRECORD_QUERY_TYPE_SKILL_ID\x10\x03\x12 \n\x1cRECORD_QUERY_TYPE_SKILL_NAME\x10\x04\x12\x1d\n\x19RECORD_QUERY_TYPE_LOCATOR\x10\x05\x12!\n\x1dRECORD_QUERY_TYPE_MODULE_NAME\x10\x06\x12\x1f\n\x1bRECORD_QUERY_TYPE_DOMAIN_ID\x10\x07\x12!\n\x1dRECORD_QUERY_TYPE_DOMAIN_NAME\x10\x08\x12 \n\x1cRECORD_QUERY_TYPE_CREATED_AT\x10\t\x12\x1c\n\x18RECORD_QUERY_TYPE_AUTHOR\x10\n\x12$\n RECORD_QUERY_TYPE_SCHEMA_VERSION\x10\x0b\x12\x1f\n\x1bRECORD_QUERY_TYPE_MODULE_ID\x10\x0c\x12\x1e\n\x1aRECORD_QUERY_TYPE_VERIFIED\x10\r\x12\x1d\n\x19RECORD_QUERY_TYPE_TRUSTED\x10\x0e\x42\xc4\x01\n\x18\x63om.agntcy.dir.search.v1B\x10RecordQueryProtoP\x01Z#github.com/agntcy/dir/api/search/v1\xa2\x02\x03\x41\x44S\xaa\x02\x14\x41gntcy.Dir.Search.V1\xca\x02\x14\x41gntcy\\Dir\\Search\\V1\xe2\x02 Agntcy\\Dir\\Search\\V1\\GPBMetadata\xea\x02\x17\x41gntcy::Dir::Search::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.search.v1.record_query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.agntcy.dir.search.v1B\020RecordQueryProtoP\001Z#github.com/agntcy/dir/api/search/v1\242\002\003ADS\252\002\024Agntcy.Dir.Search.V1\312\002\024Agntcy\\Dir\\Search\\V1\342\002 Agntcy\\Dir\\Search\\V1\\GPBMetadata\352\002\027Agntcy::Dir::Search::V1'
  _globals['_RECORDQUERYTYPE']._serialized_start=162
  _globals['_RECORDQUERYTYPE']._serialized_end=671
  _globals['_RECORDQUERY']._serialized_start=65
  _globals['_RECORDQUERY']._serialized_end=159
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/sign/v1/signature.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/sign/v1/signature.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"agntcy/dir/sign/v1/signature.proto\x12\x12\x61gntcy.dir.sign.v1\"\xe2\x02\n\tSignature\x12P\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32..agntcy.dir.sign.v1.Signature.AnnotationsEntryR\x0b\x61nnotations\x12\x1b\n\tsigned_at\x18\x02 \x01(\tR\x08signedAt\x12\x1c\n\talgorithm\x18\x03 \x01(\tR\talgorithm\x12\x1c\n\tsignature\x18\x04 \x01(\tR\tsignature\x12 \n\x0b\x63\x65rtificate\x18\x05 \x01(\tR\x0b\x63\x65rtificate\x12!\n\x0c\x63ontent_type\x18\x06 \x01(\tR\x0b\x63ontentType\x12%\n\x0e\x63ontent_bundle\x18\x07 \x01(\tR\rcontentBundle\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xb6\x01\n\x16\x63om.agntcy.dir.sign.v1B\x0eSignatureProtoP\x01Z!github.com/agntcy/dir/api/sign/v1\xa2\x02\x03\x41\x44S\xaa\x02\x12\x41gntcy.Dir.Sign.V1\xca\x02\x12\x41gntcy\\Dir\\Sign\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Sign\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Sign::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.sign.v1.signature_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.sign.v1B\016SignatureProtoP\001Z!github.com/agntcy/dir/api/sign/v1\242\002\003ADS\252\002\022Agntcy.Dir.Sign.V1\312\002\022Agntcy\\Dir\\Sign\\V1\342\002\036Agntcy\\Dir\\Sign\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Sign::V1'
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_SIGNATURE']._serialized_start=59
  _globals['_SIGNATURE']._serialized_end=413
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._serialized_start=351
  _globals['_SIGNATURE_ANNOTATIONSENTRY']._serialized_end=413
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Verification(_message.Message):
    __slots__ = ("domain",)
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    domain: DomainVerification
    def __init__(self, domain: _Optional[_Union[DomainVerification, _Mapping]] = ...) -> None: ...

class DomainVerification(_message.Message):
    __slots__ = ("domain", "method", "key_id", "verified_at")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    VERIFIED_AT_FIELD_NUMBER: _ClassVar[int]
    domain: str
    method: str
    key_id: str
    verified_at: _timestamp_pb2.Timestamp
    def __init__(self, domain: _Optional[str] = ..., method: _Optional[str] = ..., key_id: _Optional[str] = ..., verified_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from agntcy.dir.core.v1 import record_pb2 as _record_pb2
from agntcy.dir.core.v1 import referrer_pb2 as _referrer_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PushReferrerRequest(_message.Message):
    __slots__ = ("record_ref", "type", "annotations", "created_at", "data")
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    RECORD_REF_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    record_ref: _record_pb2.RecordRef
    type: str
    annotations: _containers.ScalarMap[str, str]
    created_at: str
    data: _struct_pb2.Struct
    def __init__(self, record_ref: _Optional[_Union[_record_pb2.RecordRef, _Mapping]] = ..., type: _Optional[str] = ..., annotations: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[str] = ..., data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class PushReferrerResponse(_message.Message):
    __slots__ = ("success", "error_message", "referrer_ref")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REFERRER_REF_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    referrer_ref: _referrer_pb2.ReferrerRef
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ..., referrer_ref: _Optional[_Union[_referrer_pb2.ReferrerRef, _Mapping]] = ...) -> None: ...

class PullReferrerRequest(_message.Message):
    __slots__ = ("record_ref", "referrer_type")
    RECORD_REF_FIELD_NUMBER: _ClassVar[int]
    REFERRER_TYPE_FIELD_NUMBER: _ClassVar[int]
    record_ref: _record_pb2.RecordRef
    referrer_type: str
    def __init__(self, record_ref: _Optional[_Union[_record_pb2.RecordRef, _Mapping]] = ..., referrer_type: _Optional[str] = ...) -> None: ...

class PullReferrerResponse(_message.Message):
    __slots__ = ("referrer",)
    REFERRER_FIELD_NUMBER: _ClassVar[int]
    referrer: _record_pb2.RecordReferrer
    def __init__(self, referrer: _Optional[_Union[_record_pb2.RecordReferrer, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/core/v1/referrer.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/core/v1/referrer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!agntcy/dir/core/v1/referrer.proto\x12\x12\x61gntcy.dir.core.v1\"\x1f\n\x0bReferrerRef\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63idB\xb5\x01\n\x16\x63om.agntcy.dir.core.v1B\rReferrerProtoP\x01Z!github.com/agntcy/dir/api/core/v1\xa2\x02\x03\x41\x44\x43\xaa\x02\x12\x41gntcy.Dir.Core.V1\xca\x02\x12\x41gntcy\\Dir\\Core\\V1\xe2\x02\x1e\x41gntcy\\Dir\\Core\\V1\\GPBMetadata\xea\x02\x15\x41gntcy::Dir::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.core.v1.referrer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.agntcy.dir.core.v1B\rReferrerProtoP\001Z!github.com/agntcy/dir/api/core/v1\242\002\003ADC\252\002\022Agntcy.Dir.Core.V1\312\002\022Agntcy\\Dir\\Core\\V1\342\002\036Agntcy\\Dir\\Core\\V1\\GPBMetadata\352\002\025Agntcy::Dir::Core::V1'
  _globals['_REFERRERREF']._serialized_start=57
  _globals['_REFERRERREF']._serialized_end=88
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agntcy/dir/store/v1/sync_service.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'agntcy/dir/store/v1/sync_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&agntcy/dir/store/v1/sync_service.proto\x12\x13\x61gntcy.dir.store.v1\"Y\n\x11\x43reateSyncRequest\x12\x30\n\x14remote_directory_url\x18\x01 \x01(\tR\x12remoteDirectoryUrl\x12\x12\n\x04\x63ids\x18\x02 \x03(\tR\x04\x63ids\"-\n\x12\x43reateSyncResponse\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"_\n\x10ListSyncsRequest\x12\x19\n\x05limit\x18\x02 \x01(\rH\x00R\x05limit\x88\x01\x01\x12\x1b\n\x06offset\x18\x03 \x01(\rH\x01R\x06offset\x88\x01\x01\x42\x08\n\x06_limitB\t\n\x07_offset\"\x93\x01\n\rListSyncsItem\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\x12\x37\n\x06status\x18\x02 \x01(\x0e\x32\x1f.agntcy.dir.store.v1.SyncStatusR\x06status\x12\x30\n\x14remote_directory_url\x18\x03 \x01(\tR\x12remoteDirectoryUrl\")\n\x0eGetSyncRequest\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"\xe2\x01\n\x0fGetSyncResponse\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\x12\x37\n\x06status\x18\x02 \x01(\x0e\x32\x1f.agntcy.dir.store.v1.SyncStatusR\x06status\x12\x30\n\x14remote_directory_url\x18\x03 \x01(\tR\x12remoteDirectoryUrl\x12!\n\x0c\x63reated_time\x18\x04 \x01(\tR\x0b\x63reatedTime\x12(\n\x10last_update_time\x18\x05 \x01(\tR\x0elastUpdateTime\",\n\x11\x44\x65leteSyncRequest\x12\x17\n\x07sync_id\x18\x01 \x01(\tR\x06syncId\"\x14\n\x12\x44\x65leteSyncResponse\"#\n!RequestRegistryCredentialsRequest\"\xae\x02\n\"RequestRegistryCredentialsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\x12)\n\x10registry_address\x18\x03 \x01(\tR\x0fregistryAddress\x12\'\n\x0frepository_name\x18\x06 \x01(\tR\x0erepositoryName\x12J\n\nbasic_auth\x18\x04 \x01(\x0b\x32).agntcy.dir.store.v1.BasicAuthCredentialsH\x00R\tbasicAuth\x12\x1a\n\x08insecure\x18\x07 \x01(\x08R\x08insecureB\r\n\x0b\x63redentials\"N\n\x14\x42\x61sicAuthCredentials\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password*\xcb\x01\n\nSyncStatus\x12\x1b\n\x17SYNC_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13SYNC_STATUS_PENDING\x10\x01\x12\x1b\n\x17SYNC_STATUS_IN_PROGRESS\x10\x02\x12\x16\n\x12SYNC_STATUS_FAILED\x10\x03\x12\x1e\n\x1aSYNC_STATUS_DELETE_PENDING\x10\x04\x12\x17\n\x13SYNC_STATUS_DELETED\x10\x05\x12\x19\n\x15SYNC_STATUS_COMPLETED\x10\x06\x32\x8b\x04\n\x0bSyncService\x12]\n\nCreateSync\x12&.agntcy.dir.store.v1.CreateSyncRequest\x1a\'.agntcy.dir.store.v1.CreateSyncResponse\x12X\n\tListSyncs\x12%.agntcy.dir.store.v1.ListSyncsRequest\x1a\".agntcy.dir.store.v1.ListSyncsItem0\x01\x12T\n\x07GetSync\x12#.agntcy.dir.store.v1.GetSyncRequest\x1a$.agntcy.dir.store.v1.GetSyncResponse\x12]\n\nDeleteSync\x12&.agntcy.dir.store.v1.DeleteSyncRequest\x1a\'.agntcy.dir.store.v1.DeleteSyncResponse\x12\x8d\x01\n\x1aRequestRegistryCredentials\x12\x36.agntcy.dir.store.v1.RequestRegistryCredentialsRequest\x1a\x37.agntcy.dir.store.v1.RequestRegistryCredentialsResponseB\xbe\x01\n\x17\x63om.agntcy.dir.store.v1B\x10SyncServiceProtoP\x01Z\"github.com/agntcy/dir/api/store/v1\xa2\x02\x03\x41\x44S\xaa\x02\x13\x41gntcy.Dir.Store.V1\xca\x02\x13\x41gntcy\\Dir\\Store\\V1\xe2\x02\x1f\x41gntcy\\Dir\\Store\\V1\\GPBMetadata\xea\x02\x16\x41gntcy::Dir::Store::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agntcy.dir.store.v1.sync_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.agntcy.dir.store.v1B\020SyncServiceProtoP\001Z\"github.com/agntcy/dir/api/store/v1\242\002\003ADS\252\002\023Agntcy.Dir.Store.V1\312\002\023Agntcy\\Dir\\Store\\V1\342\002\037Agntcy\\Dir\\Store\\V1\\GPBMetadata\352\002\026Agntcy::Dir::Store::V1'
  _globals['_SYNCSTATUS']._serialized_start=1211
  _globals['_SYNCSTATUS']._serialized_end=1414
  _globals['_CREATESYNCREQUEST']._serialized_start=63
  _globals['_CREATESYNCREQUEST']._serialized_end=152
  _globals['_CREATESYNCRESPONSE']._serialized_start=154
  _globals['_CREATESYNCRESPONSE']._serialized_end=199
  _globals['_LISTSYNCSREQUEST']._serialized_start=201
  _globals['_LISTSYNCSREQUEST']._serialized_end=296
  _globals['_LISTSYNCSITEM']._serialized_start=299
  _globals['_LISTSYNCSITEM']._serialized_end=446
  _globals['_GETSYNCREQUEST']._serialized_start=448
  _globals['_GETSYNCREQUEST']._serialized_end=489
  _globals['_GETSYNCRESPONSE']._serialized_start=492
  _globals['_GETSYNCRESPONSE']._serialized_end=718
  _globals['_DELETESYNCREQUEST']._serialized_start=720
  _globals['_DELETESYNCREQUEST']._serialized_end=764
  _globals['_DELETESYNCRESPONSE']._serialized_start=766
  _globals['_DELETESYNCRESPONSE']._serialized_end=786
  _globals['_REQUESTREGISTRYCREDENTIALSREQUEST']._serialized_start=788
  _globals['_REQUESTREGISTRYCREDENTIALSREQUEST']._serialized_end=823
  _globals['_REQUESTREGISTRYCREDENTIALSRESPONSE']._serialized_start=826
  _globals['_REQUESTREGISTRYCREDENTIALSRESPONSE']._serialized_end=1128
  _globals['_BASICAUTHCREDENTIALS']._serialized_start=1130
  _globals['_BASICAUTHCREDENTIALS']._serialized_end=1208
  _globals['_SYNCSERVICE']._serialized_start=1417
  _globals['_SYNCSERVICE']._serialized_end=1940
# @@protoc_insertion_point(module_scope)



from agntcy.dir.core.v1 import record_pb2 as _record_pb2
from agntcy.dir.routing.v1 import peer_pb2 as _peer_pb2
from agntcy.dir.routing.v1 import record_query_pb2 as _record_query_pb2
from agntcy.dir.search.v1 import record_query_pb2 as _record_query_pb2_1
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PublishRequest(_message.Message):
    __slots__ = ("record_refs", "queries")
    RECORD_REFS_FIELD_NUMBER: _ClassVar[int]
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    record_refs: RecordRefs
    queries: RecordQueries
    def __init__(self, record_refs: _Optional[_Union[RecordRefs, _Mapping]] = ..., queries: _Optional[_Union[RecordQueries, _Mapping]] = ...) -> None: ...

class UnpublishRequest(_message.Message):
    __slots__ = ("record_refs", "queries")
    RECORD_REFS_FIELD_NUMBER: _ClassVar[int]
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    record_refs: RecordRefs
    queries: RecordQueries
    def __init__(self, record_refs: _Optional[_Union[RecordRefs, _Mapping]] = ..., queries: _Optional[_Union[RecordQueries, _Mapping]] = ...) -> None: ...

class RecordRefs(_message.Message):
    __slots__ = ("refs",)
    REFS_FIELD_NUMBER: _ClassVar[int]
    refs: _containers.RepeatedCompositeFieldContainer[_record_pb2.RecordRef]
    def __init__(self, refs: _Optional[_Iterable[_Union[_record_pb2.RecordRef, _Mapping]]] = ...) -> None: ...

class RecordQueries(_message.Message):
    __slots__ = ("queries",)
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    queries: _containers.RepeatedCompositeFieldContainer[_record_query_pb2_1.RecordQuery]
    def __init__(self, queries: _Optional[_Iterable[_Union[_record_query_pb2_1.RecordQuery, _Mapping]]] = ...) -> None: ...

class SearchRequest(_message.Message):
    __slots__ = ("queries", "min_match_score", "limit")
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    MIN_MATCH_SCORE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    queries: _containers.RepeatedCompositeFieldContainer[_record_query_pb2.RecordQuery]
    min_match_score: int
    limit: int
    def __init__(self, queries: _Optional[_Iterable[_Union[_record_query_pb2.RecordQuery, _Mapping]]] = ..., min_match_score: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ("record_ref", "peer", "match_queries", "match_score")
    RECORD_REF_FIELD_NUMBER: _ClassVar[int]
    PEER_FIELD_NUMBER: _ClassVar[int]
    MATCH_QUERIES_FIELD_NUMBER: _ClassVar[int]
    MATCH_SCORE_FIELD_NUMBER: _ClassVar[int]
    record_ref: _record_pb2.RecordRef
    peer: _peer_pb2.Peer
    match_queries: _containers.RepeatedCompositeFieldContainer[_record_query_pb2.RecordQuery]
    match_score: int
    def __init__(self, record_ref: _Optional[_Union[_record_pb2.RecordRef, _Mapping]] = ..., peer: _Optional[_Union[_peer_pb2.Peer, _Mapping]] = ..., match_queries: _Optional[_Iterable[_Union[_record_query_pb2.RecordQuery, _Mapping]]] = ..., match_score: _Optional[int] = ...) -> None: ...

class ListRequest(_message.Message):
    __slots__ = ("queries", "limit")
    QUERIES_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    queries: _containers.RepeatedCompositeFieldContainer[_record_query_pb2.RecordQuery]
    limit: int
    def __init__(self, queries: _Optional[_Iterable[_Union[_record_query_pb2.RecordQuery, _Mapping]]] = ..., limit: _Optional[int] = ...) -> None: ...

class ListResponse(_message.Message):
    __slots__ = ("record_ref", "labels")
    RECORD_REF_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    record_ref: _record_pb2.RecordRef
    labels: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, record_ref: _Optional[_Union[_record_pb2.RecordRef, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...



from agntcy.dir.core.v1 import record_pb2 as _record_pb2
from agntcy.dir.sign.v1 import signature_pb2 as _signature_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignOptionsOIDC(_message.Message):
    __slots__ = ("fulcio_url", "rekor_url", "timestamp_url", "oidc_provider_url", "oidc_client_id", "oidc_client_secret", "skip_tlog")
    FULCIO_URL_FIELD_NUMBER: _ClassVar[int]
    REKOR_URL_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_URL_FIELD_NUMBER: _ClassVar[int]
    OIDC_PROVIDER_URL_FIELD_NUMBER: _ClassVar[int]
    OIDC_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    OIDC_CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    SKIP_TLOG_FIELD_NUMBER: _ClassVar[int]
    fulcio_url: str
    rekor_url: str
    timestamp_url: str
    oidc_provider_url: str
    oidc_client_id: str
    oidc_client_secret: str
    skip_tlog: bool
    def __init__(self, fulcio_url: _Optional[str] = ..., rekor_url: _Optional[str] = ..., timestamp_url: _Optional[str] = ..., oidc_provider_url: _Optional[str] = ..., oidc_client_id: _Optional[str] = ..., oidc_client_secret: _Optional[str] = ..., skip_tlog: bool = ...) -> None: ...

class VerifyOptionsOIDC(_message.Message):
    __slots__ = ("tuf_mirror_url", "trusted_root_path", "ignore_tlog", "ignore_tsa", "ignore_sct")
    TUF_MIRROR_URL_FIELD_NUMBER: _ClassVar[int]
    TRUSTED_ROOT_PATH_FIELD_NUMBER: _ClassVar[int]
    IGNORE_TLOG_FIELD_NUMBER: _ClassVar[int]
    IGNORE_TSA_FIELD_NUMBER: _ClassVar[int]
    IGNORE_SCT_FIELD_NUMBER: _ClassVar[int]
    tuf_mirror_url: str
    trusted_root_path: str
    ignore_tlog: bool
    ignore_tsa: bool
    ignore_sct: bool
    def __init__(self, tuf_mirror_url: _Optional[str] = ..., trusted_root_path: _Optional[str] = ..., ignore_tlog: bool = ..., ignore_tsa: bool = ..., ignore_sct: bool = ...) -> None: ...

class SignRequest(_message.Message):
    __slots__ = ("record_ref", "provider")
    RECORD_REF_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    record_ref: _record_pb2.RecordRef
    provider: SignRequestProvider
    def __init__(self, record_ref: _Optional[_Union[_record_pb2.RecordRef, _Mapping]] = ..., provider: _Optional[_Union[SignRequestProvider, _Mapping]] = ...) -> None: ...

class SignRequestProvider(_message.Message):
    __slots__ = ("key", "oidc")
    KEY_FIELD_NUMBER: _ClassVar[int]
    OIDC_FIELD_NUMBER: _ClassVar[int]
    key: SignWithKey
    oidc: SignWithOIDC
    def __init__(self, key: _Optional[_Union[SignWithKey, _Mapping]] = ..., oidc: _Optional[_Union[SignWithOIDC, _Mapping]] = ...) -> None: ...

class SignWithKey(_message.Message):
    __slots__ = ("private_key", "password")
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    private_key: str
    password: bytes
    def __init__(self, private_key: _Optional[str] = ..., password: _Optional[bytes] = ...) -> None: ...

class SignWithOIDC(_message.Message):
    __slots__ = ("id_token", "options")
    ID_TOKEN_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    id_token: str
    options: SignOptionsOIDC
    def __init__(self, id_token: _Optional[str] = ..., options: _Optional[_Union[SignOptionsOIDC, _Mapping]] = ...) -> None: ...

class SignResponse(_message.Message):
    __slots__ = ("signature",)
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    signature: _signature_pb2.Signature
    def __init__(self, signature: _Optional[_Union[_signature_pb2.Signature, _Mapping]] = ...) -> None: ...

class VerifyRequest(_message.Message):
    __slots__ = ("record_ref", "provider", "from_server")
    RECORD_REF_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    FROM_SERVER_FIELD_NUMBER: _ClassVar[int]
    record_ref: _record_pb2.RecordRef
    provider: VerifyRequestProvider
    from_server: bool
    def __init__(self, record_ref: _Optional[_Union[_record_pb2.RecordRef, _Mapping]] = ..., provider: _Optional[_Union[VerifyRequestProvider, _Mapping]] = ..., from_server: bool = ...) -> None: ...

class VerifyRequestProvider(_message.Message):
    __slots__ = ("key", "oidc", "any")
    KEY_FIELD_NUMBER: _ClassVar[int]
    OIDC_FIELD_NUMBER: _ClassVar[int]
    ANY_FIELD_NUMBER: _ClassVar[int]
    key: VerifyWithKey
    oidc: VerifyWithOIDC
    any: VerifyWithAny
    def __init__(self, key: _Optional[_Union[VerifyWithKey, _Mapping]] = ..., oidc: _Optional[_Union[VerifyWithOIDC, _Mapping]] = ..., any: _Optional[_Union[VerifyWithAny, _Mapping]] = ...) -> None: ...

class VerifyWithKey(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: str
    def __init__(self, public_key: _Optional[str] = ...) -> None: ...

class VerifyWithOIDC(_message.Message):
    __slots__ = ("issuer", "subject", "options")
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    issuer: str
    subject: str
    options: VerifyOptionsOIDC
    def __init__(self, issuer: _Optional[str] = ..., subject: _Optional[str] = ..., options: _Optional[_Union[VerifyOptionsOIDC, _Mapping]] = ...) -> None: ...

class VerifyWithAny(_message.Message):
    __slots__ = ("oidc_options",)
    OIDC_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    oidc_options: VerifyOptionsOIDC
    def __init__(self, oidc_options: _Optional[_Union[VerifyOptionsOIDC, _Mapping]] = ...) -> None: ...

class VerifyResponse(_message.Message):
    __slots__ = ("success", "signers", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    SIGNERS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    signers: _containers.RepeatedCompositeFieldContainer[SignerInfo]
    error_message: str
    def __init__(self, success: bool = ..., signers: _Optional[_Iterable[_Union[SignerInfo, _Mapping]]] = ..., error_message: _Optional[str] = ...) -> None: ...

class SignerInfo(_message.Message):
    __slots__ = ("key", "oidc")
    KEY_FIELD_NUMBER: _ClassVar[int]
    OIDC_FIELD_NUMBER: _ClassVar[int]
    key: SignerInfoKey
    oidc: SignerInfoOIDC
    def __init__(self, key: _Optional[_Union[SignerInfoKey, _Mapping]] = ..., oidc: _Optional[_Union[SignerInfoOIDC, _Mapping]] = ...) -> None: ...

class SignerInfoKey(_message.Message):
    __slots__ = ("public_key", "algorithm")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    public_key: str
    algorithm: str
    def __init__(self, public_key: _Optional[str] = ..., algorithm: _Optional[str] = ...) -> None: ...

class SignerInfoOIDC(_message.Message):
    __slots__ = ("issuer", "subject", "certificate_issuer")
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_ISSUER_FIELD_NUMBER: _ClassVar[int]
    issuer: str
    subject: str
    certificate_issuer: str
    def __init__(self, issuer: _Optional[str] = ..., subject: _Optional[str] = ..., certificate_issuer: _Optional[str] = ...) -> None: ...
